@@ -247,14 +247,14 @@ reader_convert_start (ReaderThreadData *th_data)
 		if (yelp_uri_get_section (uri)) {
 			command_line = 
 				g_strdup_printf ("%s %s?%s",
-						LIBGNOME_INFO2HTML,
-						yelp_uri_get_path (uri),
-						yelp_uri_get_section (uri));
+						 LIBGNOME_INFO2HTML,
+						 yelp_uri_get_path (uri),
+						 yelp_uri_get_section (uri));
 		} else { 
 			command_line = 
 				g_strdup_printf ("%s %s",
-						LIBGNOME_INFO2HTML,
-						yelp_uri_get_path (uri));
+						 LIBGNOME_INFO2HTML,
+						 yelp_uri_get_path (uri));
 		}
 		
 		break;
@@ -276,7 +276,7 @@ reader_convert_start (ReaderThreadData *th_data)
 
 	q_data = reader_q_data_new (reader, priv->stamp, 
 				    READER_QUEUE_TYPE_DATA);
-	
+
 	g_spawn_command_line_sync (command_line,
 				   &q_data->data,
 				   NULL,
@@ -371,7 +371,7 @@ reader_file_start (ReaderThreadData *th_data)
 	STAMP_MUTEX_UNLOCK;
 
 	result = gnome_vfs_open (&handle, 
-				 yelp_uri_get_path (uri),
+				 yelp_uri_get_path (uri), 
 				 GNOME_VFS_OPEN_READ);
 	
 	if (result != GNOME_VFS_OK) {
@@ -404,7 +404,7 @@ reader_file_start (ReaderThreadData *th_data)
 		
 		STAMP_MUTEX_UNLOCK;
 	}
-	
+
 	q_data = reader_q_data_new (reader, stamp, READER_QUEUE_TYPE_FINISHED);
 
 	g_async_queue_push (priv->thread_queue, q_data);
@@ -434,7 +434,6 @@ reader_start (ReaderThreadData *th_data)
 	YelpReader         *reader;
 	YelpReaderPriv     *priv;
 	YelpURI            *uri;
-	gchar              *str_uri;
 	
 	g_return_val_if_fail (th_data != NULL, NULL);
 
@@ -483,15 +482,11 @@ reader_start (ReaderThreadData *th_data)
 	case YELP_URI_TYPE_INDEX:
 	case YELP_URI_TYPE_PATH:
 		/* Hmm .. is this wrong or what?? */
-		break;
-	case YELP_URI_TYPE_UNKNOWN:
-		str_uri = yelp_uri_to_string (uri);
-		gnome_url_show (str_uri, NULL);
-		g_free (str_uri);
-		
 		break;
 	default:
 		g_assert_not_reached ();
+		
+		break;
 	}
 
 	return NULL;
@@ -728,7 +723,8 @@ yelp_reader_start (YelpReader *reader, YelpURI *uri)
         YelpReaderPriv   *priv;
 	ReaderThreadData *th_data;
 	gint              stamp;
-	
+	gchar              *str_uri;
+
 	g_return_val_if_fail (YELP_IS_READER (reader), FALSE);
 	g_return_val_if_fail (uri != NULL, FALSE);
 
@@ -751,6 +747,18 @@ yelp_reader_start (YelpReader *reader, YelpURI *uri)
 	th_data->uri    = yelp_uri_ref (uri);
 	th_data->stamp  = stamp;
 
+	if (yelp_uri_get_type (uri) == YELP_URI_TYPE_FILE ||
+	    yelp_uri_get_type (uri) == YELP_URI_TYPE_UNKNOWN ||
+	    yelp_uri_get_type (uri) == YELP_URI_TYPE_GHELP_OTHER) {
+		gboolean ret_val;
+		
+		str_uri = yelp_uri_to_string (uri);
+		ret_val = gnome_url_show (str_uri, NULL);
+		g_free (str_uri);
+
+		return ret_val;
+	}
+
 	if (yelp_uri_get_type (uri) == YELP_URI_TYPE_DOCBOOK_XML || 
 	    yelp_uri_get_type (uri) == YELP_URI_TYPE_DOCBOOK_SGML) {
 		const gchar *document;
